@@ -423,9 +423,9 @@ class Generator:
         return f"{expression_sql}{op_sql} {this_sql}{on_sql}"
 
     def lambda_sql(self, expression):
-        return self.no_identify(
-            lambda: f"({self.expressions(expression, flat=True)}) -> {self.sql(expression, 'this')}"
-        )
+        args = self.expressions(expression, flat=True)
+        args = f"({args})" if len(args) > 1 else args
+        return self.no_identify(lambda: f"{args} -> {self.sql(expression, 'this')}")
 
     def lateral_sql(self, expression):
         this = self.sql(expression, "this")
