@@ -114,6 +114,7 @@ class TokenType(AutoName):
     HAVING = auto()
     HINT = auto()
     IF = auto()
+    ILIKE = auto()
     IN = auto()
     INNER = auto()
     INSERT = auto()
@@ -162,6 +163,7 @@ class TokenType(AutoName):
     THEN = auto()
     TRUE = auto()
     TRUNCATE = auto()
+    TRY_CAST = auto()
     UNBOUNDED = auto()
     UNION = auto()
     UNNEST = auto()
@@ -303,6 +305,7 @@ class Tokenizer:
         "GROUP BY": TokenType.GROUP,
         "HAVING": TokenType.HAVING,
         "IF": TokenType.IF,
+        "ILIKE": TokenType.ILIKE,
         "IN": TokenType.IN,
         "INNER": TokenType.INNER,
         "INSERT": TokenType.INSERT,
@@ -352,6 +355,7 @@ class Tokenizer:
         "TIME": TokenType.TIME,
         "TRUE": TokenType.TRUE,
         "TRUNCATE": TokenType.TRUNCATE,
+        "TRY_CAST": TokenType.TRY_CAST,
         "UNBOUNDED": TokenType.UNBOUNDED,
         "UNION": TokenType.UNION,
         "UNNEST": TokenType.UNNEST,
